<?php

/**
 * @file
 * Admin page callbacks.
 */

/**
 * Display the liste of rates for a shipping service.
 *
 * @param $name
 *   The name of the view to embed.
 * @param $display_id
 *   The display id to embed. If unsure, use 'default', as it will always be
 *   valid. But things like 'page' or 'block' should work here.
 * @param $method_id
 *   The shipping method id.
 * @param $service_name
 *   The shipping service machine name.
 *
 * @return array
 *   The renderable array.
 */
function commerce_shipping_rate_views_embed_view($name, $display_id = 'default', $method_id, $service_name) {
  $content = array();

  $content['rates'] = array(
    '#markup' => views_embed_view($name, $display_id, $method_id, $service_name),
  );

  return $content;
}

/**
 * Display an overview of all the shipping services by method.
 *
 * @return array
 *   The renderable array.
 */
function commerce_shipping_rates_methods_overview($method) {
  foreach (commerce_shipping_methods() as $method_id => $method) {
    // Convert underscores to hyphens for the menu item argument.
    $method_name_arg = strtr($method_id, '_', '-');
    $items[] = array(
      '#prefix' => '<p>',
      '#suffix' => '</p>',
      '#markup' => l($method['title'], 'admin/commerce/config/shipping-rates/' . $method_name_arg),
    );
  }
  return $items;
}

/**
 * Display an overview of all the shipping services by method.
 *
 * @return array
 *   The renderable array.
 */
function commerce_shipping_rates_services_overview($method_id) {
  $method = commerce_shipping_method_load($method_id);
  $content = array();
  $content = array();
  $content = array(
      '#type' => 'fieldset',
      '#title' => $method['title'],
      '#attributes' => array('class' => array('shipping-rates-method')),
  );

  // Convert underscores to hyphens for the menu item argument.
  $method_name_arg = strtr($method['name'], '_', '-');

  // Create links foreach services to manage rates.
  foreach (commerce_shipping_services($method['name']) as $service_name => $service) {
    $content[strtr($service_name, '-', '_')] = array(
        '#type' => 'container',
        '#attributes' => array('class' => array('shipping-rates-service')),
    );
    // Convert underscores to hyphens for the menu item argument.
    $service_name_arg = 'shipping-rates' . '-' . strtr($service_name, '_', '-');

    $content[strtr($service_name, '-', '_')]['link'] = array(
      '#prefix' => '<p>',
      '#suffix' => '</p>',
      '#markup' => l(t('Manage %service rates', array('%service' => $service['display_title'])), 'admin/commerce/config/shipping-rates/' . $method_name_arg . '/' . $service_name_arg . '/rates', array('html' => TRUE)),
    );
  }

  return $content;
}
